BMFWeatherDataType enum

天气数据类型枚举

Inheritance
  • Object
  • Enum
  • BMFWeatherDataType

Values

Now → const BMFWeatherDataType

实时天气预报

Forecasts → const BMFWeatherDataType

未来五天天气预报

ForecastsForHour → const BMFWeatherDataType

按小时天气预报,高级字段

LifeIndex → const BMFWeatherDataType

生活指数,仅支持国内,高级字段

Alert → const BMFWeatherDataType

天气事件预警,仅支持国内,高级字段

All → const BMFWeatherDataType

以上全部,高级字段获取对应权限后可返回

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<BMFWeatherDataType>
A constant List of the values in this enum, in order of their declaration.